Installing peewee — peewee 2.0.4 documentation

### Navigation

- index
- next |
- previous |
- peewee 2.0.4 documentation »

# Installing peewee

Most users will want to simply install the latest version, hosted on PyPI:

    pip install peewee

## Installing Manually

The project is hosted at https://github.com/coleifer/peewee and can be installed manually:

    git clone https://github.com/coleifer/peewee.git
    cd peewee
    python setup.py install

## Running tests

You can test your installation by running the test suite.

    python setup.py test

### Navigation

- index
- next |
- previous |
- peewee 2.0.4 documentation »